==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/DownwardAPIVolumeFileFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface DownwardAPIVolumeFileFluent<A extends io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildFieldRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectFieldSelector getFieldRef();
  public io.fabric8.kubernetes.api.model.ObjectFieldSelector buildFieldRef();
  public A withFieldRef(io.fabric8.kubernetes.api.model.ObjectFieldSelector fieldRef);
  public java.lang.Boolean hasFieldRef();
  public A withNewFieldRef(java.lang.String apiVersion,java.lang.String fieldPath);
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.FieldRefNested<A> withNewFieldRef();
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.FieldRefNested<A> withNewFieldRefLike(io.fabric8.kubernetes.api.model.ObjectFieldSelector item);
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.FieldRefNested<A> editFieldRef();
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.FieldRefNested<A> editOrNewFieldRef();
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.FieldRefNested<A> editOrNewFieldRefLike(io.fabric8.kubernetes.api.model.ObjectFieldSelector item);
  public java.lang.Integer getMode();
  public A withMode(java.lang.Integer mode);
  public java.lang.Boolean hasMode();
  public java.lang.String getPath();
  public A withPath(java.lang.String path);
  public java.lang.Boolean hasPath();
  
  /**
   * Method is deprecated. use withPath instead.
   */
  @java.lang.Deprecated
  public A withNewPath(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildResourceFieldRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ResourceFieldSelector getResourceFieldRef();
  public io.fabric8.kubernetes.api.model.ResourceFieldSelector buildResourceFieldRef();
  public A withResourceFieldRef(io.fabric8.kubernetes.api.model.ResourceFieldSelector resourceFieldRef);
  public java.lang.Boolean hasResourceFieldRef();
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.ResourceFieldRefNested<A> withNewResourceFieldRef();
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.ResourceFieldRefNested<A> withNewResourceFieldRefLike(io.fabric8.kubernetes.api.model.ResourceFieldSelector item);
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.ResourceFieldRefNested<A> editResourceFieldRef();
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.ResourceFieldRefNested<A> editOrNewResourceFieldRef();
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.ResourceFieldRefNested<A> editOrNewResourceFieldRefLike(io.fabric8.kubernetes.api.model.ResourceFieldSelector item);
  public interface FieldRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ObjectFieldSelectorFluent<io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.FieldRefNested<N>>{
    public N and();
    public N endFieldRef();
    
  }
  public interface ResourceFieldRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ResourceFieldSelectorFluent<io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.ResourceFieldRefNested<N>>{
    public N and();
    public N endResourceFieldRef();
    
  }
  
}

==> kubernetes-model-core-5.12.1-sources.jar: io/fabric8/kubernetes/api/model/DownwardAPIVolumeFileFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface DownwardAPIVolumeFileFluent<A extends io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildFieldRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectFieldSelector getFieldRef();
  public io.fabric8.kubernetes.api.model.ObjectFieldSelector buildFieldRef();
  public A withFieldRef(io.fabric8.kubernetes.api.model.ObjectFieldSelector fieldRef);
  public java.lang.Boolean hasFieldRef();
  public A withNewFieldRef(java.lang.String apiVersion,java.lang.String fieldPath);
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.FieldRefNested<A> withNewFieldRef();
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.FieldRefNested<A> withNewFieldRefLike(io.fabric8.kubernetes.api.model.ObjectFieldSelector item);
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.FieldRefNested<A> editFieldRef();
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.FieldRefNested<A> editOrNewFieldRef();
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.FieldRefNested<A> editOrNewFieldRefLike(io.fabric8.kubernetes.api.model.ObjectFieldSelector item);
  public java.lang.Integer getMode();
  public A withMode(java.lang.Integer mode);
  public java.lang.Boolean hasMode();
  public java.lang.String getPath();
  public A withPath(java.lang.String path);
  public java.lang.Boolean hasPath();
  
  /**
   * Method is deprecated. use withPath instead.
   */
  @java.lang.Deprecated
  public A withNewPath(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildResourceFieldRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ResourceFieldSelector getResourceFieldRef();
  public io.fabric8.kubernetes.api.model.ResourceFieldSelector buildResourceFieldRef();
  public A withResourceFieldRef(io.fabric8.kubernetes.api.model.ResourceFieldSelector resourceFieldRef);
  public java.lang.Boolean hasResourceFieldRef();
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.ResourceFieldRefNested<A> withNewResourceFieldRef();
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.ResourceFieldRefNested<A> withNewResourceFieldRefLike(io.fabric8.kubernetes.api.model.ResourceFieldSelector item);
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.ResourceFieldRefNested<A> editResourceFieldRef();
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.ResourceFieldRefNested<A> editOrNewResourceFieldRef();
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.ResourceFieldRefNested<A> editOrNewResourceFieldRefLike(io.fabric8.kubernetes.api.model.ResourceFieldSelector item);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface FieldRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ObjectFieldSelectorFluent<io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.FieldRefNested<N>>{
    public N and();
    public N endFieldRef();
    
  }
  public interface ResourceFieldRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ResourceFieldSelectorFluent<io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.ResourceFieldRefNested<N>>{
    public N and();
    public N endResourceFieldRef();
    
  }
  
}
